@@ -10,6 +10,7 @@ import com.unciv.models.ruleset.unique.UniqueTarget
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.ui.components.extensions.colorFromRGB
 import com.unciv.ui.components.fonts.Fonts
+import com.unciv.ui.objectdescriptions.uniquesToCivilopediaTextLines
 import com.unciv.ui.screens.civilopediascreen.FormattedLine
 
 class Era : RulesetObject() {
@@ -53,8 +54,7 @@ class Era : RulesetObject() {
             .filter { it.era() == name }
             .map { FormattedLine(it.name, it.makeLink()) })
 
-        if (uniques.isNotEmpty()) yield(FormattedLine())
-        yieldAll(uniqueObjects.asSequence().map { FormattedLine(it) })
+        yieldAll(uniquesToCivilopediaTextLines())
 
         val eraGatedObjects = getEraGatedObjects(ruleset).toList()
         if (eraGatedObjects.isEmpty()) return@sequence
