@@ -41,6 +41,7 @@ import com.unciv.ui.components.extensions.isShiftKeyPressed
 import com.unciv.ui.components.extensions.surroundWithCircle
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.input.ActivationTypes
+import com.unciv.ui.components.input.ClickableCircle
 import com.unciv.ui.components.input.KeyCharAndCode
 import com.unciv.ui.components.input.KeyboardBinding
 import com.unciv.ui.components.input.keyShortcuts
@@ -480,12 +481,14 @@ class WorldMapHolder(
             val unitGroup = UnitGroup(unit, 48f).surroundWithCircle(68f, resizeActor = false)
             unitGroup.circle.color = Color.GRAY.cpy().apply { a = 0.5f }
             if (unit.currentMovement == 0f) unitGroup.color.a = 0.66f
-            unitGroup.touchable = Touchable.enabled
-            unitGroup.onClick {
+            val clickableCircle = ClickableCircle(68f)
+            clickableCircle.touchable = Touchable.enabled
+            clickableCircle.onClick {
                 worldScreen.bottomUnitTable.selectUnit(unit, Gdx.input.isShiftKeyPressed())
                 worldScreen.shouldUpdate = true
                 removeUnitActionOverlay()
             }
+            unitGroup.addActor(clickableCircle)
             table.add(unitGroup)
         }
 
@@ -655,7 +658,7 @@ class WorldMapHolder(
                 val city = unitTable.selectedCity!!
                 updateBombardableTilesForSelectedCity(city)
                 // We still want to show road paths to the selected city if they are present
-                if (unitTable.selectedUnitIsConnectingRoad){
+                if (unitTable.selectedUnitIsConnectingRoad) {
                     updateTilesForSelectedUnit(unitTable.selectedUnits[0])
                 }
             }
@@ -715,11 +718,10 @@ class WorldMapHolder(
 
         // Z-Layer: 0
         // Highlight suitable tiles in road connecting mode
-        if (worldScreen.bottomUnitTable.selectedUnitIsConnectingRoad){
+        if (worldScreen.bottomUnitTable.selectedUnitIsConnectingRoad) {
             val validTiles = unit.civ.gameInfo.tileMap.tileList.filter {
                 MapPathing.isValidRoadPathTile(unit, it)
             }
-            unit.civ.gameInfo.civilizations
             val connectRoadTileOverlayColor = Color.RED
             for (tile in validTiles)  {
                 tileGroups[tile]!!.layerOverlay.showHighlight(connectRoadTileOverlayColor, 0.3f)
@@ -796,10 +798,10 @@ class WorldMapHolder(
             if (currTileIndex != -1) {
                 val futureTiles = unit.automatedRoadConnectionPath!!.filterIndexed { index, _ ->
                     index > currTileIndex
-                }.map{tilePos ->
+                }.map { tilePos ->
                     tileMap[tilePos]
                 }
-                for (tile in futureTiles){
+                for (tile in futureTiles) {
                     tileGroups[tile]!!.layerOverlay.showHighlight(Color.ORANGE, if (UncivGame.Current.settings.singleTapMove) 0.7f else 0.3f)
                 }
             }
